@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE DeriveGeneric #-}
 {-# LANGUAGE FlexibleInstances #-}
 {-# LANGUAGE GeneralizedNewtypeDeriving #-}
@@ -115,7 +116,12 @@ import Data.Binary.Put (
 import Data.ByteString (ByteString)
 import qualified Data.ByteString as BS
 import qualified Data.ByteString.Lazy as LBS
-import Data.Foldable (foldl', toList)
+
+{- HLINT ignore "Use fewer imports" -}
+#if !MIN_VERSION_base(4,20,0)
+import Data.Foldable (foldl')
+#endif
+import Data.Foldable (toList)
 import Data.List (isPrefixOf)
 import Data.Maybe (fromJust, fromMaybe)
 import Data.Sequence (Seq)
